@@ -6,6 +6,7 @@ dataProcessor = DataProcessor(5)
 # Y is the [The number of entries * 1] label list
 X, Y = dataProcessor.dataProcessingForRNN("xss-20000.txt", "labeled_data.csv")
 X, Y = dataProcessor.dataProcessingForSVM("xss-20000.txt", "labeled_data.csv")
-print(len(X[0]))
-print(len(X))
+input = "Hello Madam http:fdaoj is good /aspcms/product/2016-12-8/496.html?word=angelina&cl=3&s=angelina&tn=bds&si=www.baidu.com&ct=%22%3E%3Cimg%20src=1%20onerror=alert(1)%3E"
+print(dataProcessor.inputProcessingForSVM(input))
+print(dataProcessor.inputProcessingForRNN(input))
 
